@@ -17,7 +17,7 @@ fs.exists("../dist/index.html",function(exists){
   }
 });
 
-webpackCfg.plugins.push(new webpack.HotModuleReplacementPlugin());
+//webpackCfg.plugins.push(new webpack.HotModuleReplacementPlugin());
 
 var compiler = webpack(webpackCfg), modulePath = webpackCfg.output.publicPath;
 var port = 5389;
