@@ -47,7 +47,7 @@ import NotFound from '../NotFound';
 const routes = (
     <Provider store={store}>
     <Router history={browserHistory}>
-    <Route path="/"<%=data.endName%>"/"<%=data.moduleName%>"" component={RootApp}>
+    <Route path="/<%=data.endName%>/<%=data.moduleName%>" component={RootApp}>
     <Route path="home" component={Home} />
     <Route path="list" component={List} />
     <Route path="add" component={Add} />
