@@ -92,14 +92,7 @@ public class UserController {
     	 String referer = request.getHeader("refererValue");
     	 System.out.println("Last request header: referer:" + referer + "serverPath " + request.getServletPath());
     	 
-    	 Enumeration<String> em = request.getHeaderNames();
-    	 while (em.hasMoreElements()) {
-    		    String name = (String) em.nextElement();
-    		    String value = request.getHeader(name);
-    		    System.out.println("Last request header: KeyName:" + name + "Value:" + value);
-    		}
-    		
-    	 //WebAuthenticationDetails details = (WebAuthenticationDetails)SecurityContextHolder.getContext().getAuthentication().getDetails();
+    	
     	
     	if (device.isMobile() || device.isTablet()){
     		return "redirect:/client/user/login";
