@@ -75,7 +75,7 @@ public class <%=data.moduleName%>Controller {
                                    var keyName = field;
 
                                    var refer = fieldDef.refer;
-                                   if (refer) {
+                                   if (refer&&(refer.map==="ManyToOne")) {
                                    var clsName = data.firstUpper(refer.module);
                                    var fieldNameUpper = data.firstUpper(field);
                                    var idType = data.moduleDefine['id'].type;
@@ -85,6 +85,21 @@ public class <%=data.moduleName%>Controller {
                    	  <%=clsName%> <%=field%>Obj = <%=refer.module%>Service.findById(<%=field%>Id);
                       item.set<%=fieldNameUpper%>(<%=field%>Obj);
                    }
+         <%}else if(refer&&(refer.map==="OneToMany")){
+         	  var clsName = data.firstUpper(refer.module);
+        	  var fieldNameUpper = data.firstUpper(field);
+        	  var idType = data.moduleDefine['id'].type;
+         %>
+
+
+    	           for(int i=0; i < item.get<%=fieldNameUpper%>List().size();i++){
+    	        	   <%=clsName%> oldOne = item.get<%=fieldNameUpper%>List().get(i);
+    	        	   if (oldOne.getId() == null){
+    	        		   item.get<%=fieldNameUpper%>List().remove(i);
+    	        		    <%=clsName%> newOne = <%=refer.module%>Service.save(oldOne);
+    	        		   item.get<%=fieldNameUpper%>List().add(newOne);
+    	        	   }
+    	           }
 
          <%}}%>
 
@@ -113,7 +128,7 @@ public class <%=data.moduleName%>Controller {
                            var keyName = field;
 
                            var refer = fieldDef.refer;
-                           if (refer) {
+                           if (refer&&(refer.map==="ManyToOne")) {
                            var clsName = data.firstUpper(refer.module);
                            var fieldNameUpper = data.firstUpper(field);
                            var idType = data.moduleDefine['id'].type;
@@ -124,6 +139,22 @@ public class <%=data.moduleName%>Controller {
               item.set<%=fieldNameUpper%>(<%=field%>Obj);
            }
 
+             <%}else if (refer&&(refer.map==="OneToMany")){
+            	  var clsName = data.firstUpper(refer.module);
+                  var fieldNameUpper = data.firstUpper(field);
+                  var idType = data.moduleDefine['id'].type;
+              %>
+
+
+                	           for(int i=0; i < item.get<%=fieldNameUpper%>List().size();i++){
+                	        	   <%=clsName%> oldOne = item.get<%=fieldNameUpper%>List().get(i);
+                	        	   if (oldOne.getId() == null){
+                	        		   item.get<%=fieldNameUpper%>List().remove(i);
+                	        		    <%=clsName%> newOne = <%=refer.module%>Service.save(oldOne);
+                	        		   item.get<%=fieldNameUpper%>List().add(newOne);
+                	        	   }
+                	           }
+
            <%}}%>
 
 
